==> keycloak-model-map-18.0.2-sources.jar: org/keycloak/models/map/realm/entity/MapComponentEntityDelegate.java <==
package org.keycloak.models.map.realm.entity;
public class MapComponentEntityDelegate implements org.keycloak.models.map.realm.entity.MapComponentEntity {
    private final org.keycloak.models.map.common.delegate.DelegateProvider<org.keycloak.models.map.realm.entity.MapComponentEntity> delegateProvider;
    public MapComponentEntityDelegate(org.keycloak.models.map.common.delegate.DelegateProvider<org.keycloak.models.map.realm.entity.MapComponentEntity> delegateProvider) {
        this.delegateProvider = delegateProvider;
    }
    @Override public boolean isUpdated() {
        return delegateProvider.isUpdated();
    }
    @Override public String getId() {
        return delegateProvider.getDelegate(true, org.keycloak.models.map.realm.entity.MapComponentEntityFields.ID).getId();
    }
    @Override public void setId(String id) {
        delegateProvider.getDelegate(false, org.keycloak.models.map.realm.entity.MapComponentEntityFields.ID, id).setId(id);
    }
    @Override public String getName() {
        return delegateProvider.getDelegate(true, org.keycloak.models.map.realm.entity.MapComponentEntityFields.NAME).getName();
    }
    @Override public void setName(String name) {
        delegateProvider.getDelegate(false, org.keycloak.models.map.realm.entity.MapComponentEntityFields.NAME, name).setName(name);
    }
    @Override public String getProviderId() {
        return delegateProvider.getDelegate(true, org.keycloak.models.map.realm.entity.MapComponentEntityFields.PROVIDER_ID).getProviderId();
    }
    @Override public void setProviderId(String providerId) {
        delegateProvider.getDelegate(false, org.keycloak.models.map.realm.entity.MapComponentEntityFields.PROVIDER_ID, providerId).setProviderId(providerId);
    }
    @Override public String getProviderType() {
        return delegateProvider.getDelegate(true, org.keycloak.models.map.realm.entity.MapComponentEntityFields.PROVIDER_TYPE).getProviderType();
    }
    @Override public void setProviderType(String providerType) {
        delegateProvider.getDelegate(false, org.keycloak.models.map.realm.entity.MapComponentEntityFields.PROVIDER_TYPE, providerType).setProviderType(providerType);
    }
    @Override public String getSubType() {
        return delegateProvider.getDelegate(true, org.keycloak.models.map.realm.entity.MapComponentEntityFields.SUB_TYPE).getSubType();
    }
    @Override public void setSubType(String subType) {
        delegateProvider.getDelegate(false, org.keycloak.models.map.realm.entity.MapComponentEntityFields.SUB_TYPE, subType).setSubType(subType);
    }
    @Override public String getParentId() {
        return delegateProvider.getDelegate(true, org.keycloak.models.map.realm.entity.MapComponentEntityFields.PARENT_ID).getParentId();
    }
    @Override public void setParentId(String parentId) {
        delegateProvider.getDelegate(false, org.keycloak.models.map.realm.entity.MapComponentEntityFields.PARENT_ID, parentId).setParentId(parentId);
    }
    @Override public java.util.Map<String,java.util.List<String>> getConfig() {
        return delegateProvider.getDelegate(true, org.keycloak.models.map.realm.entity.MapComponentEntityFields.CONFIG).getConfig();
    }
    @Override public void setConfig(java.util.Map<String,java.util.List<String>> config) {
        delegateProvider.getDelegate(false, org.keycloak.models.map.realm.entity.MapComponentEntityFields.CONFIG, config).setConfig(config);
    }
}

==> keycloak-model-map-21.0.0-sources.jar: org/keycloak/models/map/realm/entity/MapComponentEntityDelegate.java <==
package org.keycloak.models.map.realm.entity;
@javax.annotation.processing.Generated("org.keycloak.models.map.processor.GenerateEntityImplementationsProcessor")
public class MapComponentEntityDelegate implements org.keycloak.models.map.realm.entity.MapComponentEntity, org.keycloak.models.map.common.delegate.HasDelegateProvider<org.keycloak.models.map.realm.entity.MapComponentEntity> {
    private final org.keycloak.models.map.common.delegate.DelegateProvider<org.keycloak.models.map.realm.entity.MapComponentEntity> delegateProvider;
    public MapComponentEntityDelegate(org.keycloak.models.map.common.delegate.DelegateProvider<org.keycloak.models.map.realm.entity.MapComponentEntity> delegateProvider) {
        this.delegateProvider = delegateProvider;
    }
    public org.keycloak.models.map.common.delegate.DelegateProvider<org.keycloak.models.map.realm.entity.MapComponentEntity> getDelegateProvider() {
        return this.delegateProvider;
    }
    @Override public boolean isUpdated() {
        return delegateProvider.isUpdated();
    }
    @Override public String getId() {
        return delegateProvider.getDelegate(true, org.keycloak.models.map.realm.entity.MapComponentEntityFields.ID).getId();
    }
    @Override public void setId(String id) {
        delegateProvider.getDelegate(false, org.keycloak.models.map.realm.entity.MapComponentEntityFields.ID, id).setId(id);
    }
    @Override public String getName() {
        return delegateProvider.getDelegate(true, org.keycloak.models.map.realm.entity.MapComponentEntityFields.NAME).getName();
    }
    @Override public void setName(String name) {
        delegateProvider.getDelegate(false, org.keycloak.models.map.realm.entity.MapComponentEntityFields.NAME, name).setName(name);
    }
    @Override public String getProviderId() {
        return delegateProvider.getDelegate(true, org.keycloak.models.map.realm.entity.MapComponentEntityFields.PROVIDER_ID).getProviderId();
    }
    @Override public void setProviderId(String providerId) {
        delegateProvider.getDelegate(false, org.keycloak.models.map.realm.entity.MapComponentEntityFields.PROVIDER_ID, providerId).setProviderId(providerId);
    }
    @Override public String getProviderType() {
        return delegateProvider.getDelegate(true, org.keycloak.models.map.realm.entity.MapComponentEntityFields.PROVIDER_TYPE).getProviderType();
    }
    @Override public void setProviderType(String providerType) {
        delegateProvider.getDelegate(false, org.keycloak.models.map.realm.entity.MapComponentEntityFields.PROVIDER_TYPE, providerType).setProviderType(providerType);
    }
    @Override public String getSubType() {
        return delegateProvider.getDelegate(true, org.keycloak.models.map.realm.entity.MapComponentEntityFields.SUB_TYPE).getSubType();
    }
    @Override public void setSubType(String subType) {
        delegateProvider.getDelegate(false, org.keycloak.models.map.realm.entity.MapComponentEntityFields.SUB_TYPE, subType).setSubType(subType);
    }
    @Override public String getParentId() {
        return delegateProvider.getDelegate(true, org.keycloak.models.map.realm.entity.MapComponentEntityFields.PARENT_ID).getParentId();
    }
    @Override public void setParentId(String parentId) {
        delegateProvider.getDelegate(false, org.keycloak.models.map.realm.entity.MapComponentEntityFields.PARENT_ID, parentId).setParentId(parentId);
    }
    @Override public java.util.Map<String,java.util.List<String>> getConfig() {
        return delegateProvider.getDelegate(true, org.keycloak.models.map.realm.entity.MapComponentEntityFields.CONFIG).getConfig();
    }
    @Override public void setConfig(java.util.Map<String,java.util.List<String>> config) {
        delegateProvider.getDelegate(false, org.keycloak.models.map.realm.entity.MapComponentEntityFields.CONFIG, config).setConfig(config);
    }
}
